@@ -2,7 +2,7 @@
 # extension modules created with SIP.  It provides information about file
 # locations, version numbers etc., and provides some classes and functions.
 #
-# Copyright (c) 2015 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2018 Riverbank Computing Limited <info@riverbankcomputing.com>
 #
 # This file is part of SIP.
 #
@@ -35,14 +35,15 @@ _pkg_config = {
     'py_conf_inc_dir':    '/usr/local/include/python2.7',
     'py_inc_dir':         '/usr/local/include/python2.7',
     'py_lib_dir':         '/usr/local/lib/python2.7/config',
-    'py_version':         0x02070e,
+    'py_version':         0x020710,
     'qt_framework':       0,
     'sip_bin':            '/usr/local/bin/sip',
     'sip_config_args':    '-b /usr/local/bin -d /usr/local/lib/python2.7/site-packages -e /usr/local/include/python2.7 -v /usr/local/share/sip INCDIR=/usr/local/include LIBDIR=/usr/local/lib CC=cc CXX=c++ CFLAGS=-O2 -pipe   CXXFLAGS=-O2 -pipe  ',
     'sip_inc_dir':        '/usr/local/include/python2.7',
-    'sip_mod_dir':        '/usr/local/lib/python2.7/site-packages',
-    'sip_version':        0x041303,
-    'sip_version_str':    '4.19.3',
+    'sip_module_dir':     '/usr/local/lib/python2.7/site-packages',
+    'sip_root_dir':       '/usr/local/lib/python2.7/site-packages',
+    'sip_version':        0x041311,
+    'sip_version_str':    '4.19.17',
     'universal':          ''
 }
 
@@ -335,7 +336,8 @@ class Makefile:
         installs is a list of extra install targets.  Each element is a two
         part list, the first of which is the source and the second is the
         destination.  If the source is another list then it is a set of source
-        files and the destination is a directory.
+        files and the destination is a directory.  If the destination is None
+        then the source is a command to run.
         universal is the name of the SDK if the target is a MacOS/X universal
         binary.  If it is None then the value is taken from the configuration.
         arch is the space separated MacOS/X architectures to build.  If it is
@@ -1255,7 +1257,10 @@ class Makefile:
                 self._installs = [self._installs]
 
             for src, dst in self._installs:
-                self.install_file(mfile, src, dst)
+                if dst is None:
+                    mfile.write("\t%s\n" % src)
+                else:
+                    self.install_file(mfile, src, dst)
 
         self.generate_target_clean(mfile)
 
